@@ -27,6 +27,10 @@
 #define DEBUG_FLAG NEMO_DEBUG_ACTIONS
 #include <libnemo-private/nemo-debug.h>
 
+#if (!GLIB_CHECK_VERSION(2,50,0))
+#define g_drive_is_removable g_drive_is_media_removable
+#endif
+
 G_DEFINE_TYPE (NemoAction, nemo_action,
 	       GTK_TYPE_ACTION);
 
@@ -80,6 +84,8 @@ dbus_condition_free (gpointer data)
     DBusCondition *cond = (DBusCondition *) data;
     g_free (cond->name);
     g_bus_unwatch_name (cond->watch_id);
+
+    g_free (cond);
 }
 
 static void
@@ -514,10 +520,11 @@ nemo_action_constructed (GObject *object)
     g_free (icon_name);
     g_free (stock_id);
     g_free (exec);
-    g_strfreev (ext);
     g_free (parent_dir);
     g_free (quote_type_string);
     g_free (separator);
+    g_strfreev (ext);
+    g_strfreev (mimes);
     g_strfreev (conditions);
     g_key_file_free (key_file);
 }
@@ -1431,7 +1438,7 @@ nemo_action_get_visibility (NemoAction *action, GList *selection, NemoFile *pare
                     if (mount) {
                         GDrive *drive = g_mount_get_drive (mount);
                         if (drive) {
-                            if (g_drive_is_media_removable (drive))
+                            if (g_drive_is_removable (drive))
                                 is_removable = TRUE;
                             g_object_unref (drive);
                         }
@@ -1526,9 +1533,10 @@ nemo_action_get_visibility (NemoAction *action, GList *selection, NemoFile *pare
                     }
                 }
             }
-            g_free (filename);
         }
 
+        g_free (filename);
+
         if (mime_count > 0) {
             for (i = 0; i < mime_count; i++) {
                 if (nemo_file_is_mime_type (NEMO_FILE (iter->data), mimetypes[i])) {
