@@ -213,6 +213,7 @@ gboolean                nemo_file_is_user_special_directory         (NemoFile
 gboolean		nemo_file_is_archive			(NemoFile			*file);
 gboolean                nemo_file_is_in_trash                       (NemoFile                   *file);
 gboolean                nemo_file_is_in_recent                      (NemoFile                   *file);
+gboolean                nemo_file_is_in_admin                       (NemoFile                   *file);
 gboolean                nemo_file_is_in_desktop                     (NemoFile                   *file);
 gboolean		nemo_file_is_home				(NemoFile                   *file);
 gboolean                nemo_file_is_desktop_directory              (NemoFile                   *file);
@@ -229,6 +230,7 @@ NemoRequestStatus   nemo_file_get_deep_counts                   (NemoFile
 									 goffset                         *total_size,
 									 gboolean                        force);
 gboolean                nemo_file_should_show_thumbnail             (NemoFile                   *file);
+void                    nemo_file_delete_thumbnail                  (NemoFile                   *file);
 gboolean                nemo_file_should_show_directory_item_count  (NemoFile                   *file);
 gboolean                nemo_file_should_show_type                  (NemoFile                   *file);
 GList *                 nemo_file_get_keywords                      (NemoFile                   *file);
@@ -449,8 +451,7 @@ char *                  nemo_file_get_drop_target_uri               (NemoFile
 
 GIcon *                 nemo_file_get_gicon                         (NemoFile                   *file,
                                                                      NemoFileIconFlags           flags);
-GIcon *                 nemo_file_get_emblemed_icon                 (NemoFile                   *file,
-                                                                     NemoFileIconFlags           flags);
+gchar *                 nemo_file_get_control_icon_name             (NemoFile                   *file);
 
 NemoIconInfo *      nemo_file_get_icon                          (NemoFile                   *file,
 									 int                             size,
