@@ -48,10 +48,8 @@
 
 #include "nemo-file-private.h"
 
-/* turn this on to see messages about thumbnail creation */
-#if 0
-#define DEBUG_THUMBNAILS
-#endif
+#define DEBUG_FLAG NEMO_DEBUG_THUMBNAILS
+#include <libnemo-private/nemo-debug.h>
 
 /* Should never be a reasonable actual mtime */
 #define INVALID_MTIME 0
@@ -170,9 +168,8 @@ thumbnail_thread_starter_cb (gpointer data)
 	pthread_attr_setdetachstate (&thread_attributes,
 				     PTHREAD_CREATE_DETACHED);
 
-#ifdef DEBUG_THUMBNAILS
-	g_message ("(Main Thread) Creating thumbnails thread\n");
-#endif
+	DEBUG ("(Main Thread) Creating thumbnails thread");
+
 	/* We set a flag to indicate the thread is running, so we don't create
 	   a new one. We don't need to lock a mutex here, as the thumbnail
 	   thread isn't running yet. And we know we won't create the thread
@@ -286,9 +283,8 @@ nemo_thumbnail_remove_from_queue (const char *file_uri)
 {
 	GList *node;
 	
-#ifdef DEBUG_THUMBNAILS
-	g_message ("(Remove from queue) Locking mutex\n");
-#endif
+	DEBUG ("(Remove from queue) Locking mutex");
+
 	pthread_mutex_lock (&thumbnails_mutex);
 
 	/*********************************
@@ -309,9 +305,8 @@ nemo_thumbnail_remove_from_queue (const char *file_uri)
 	 * MUTEX UNLOCKED
 	 *********************************/
 	
-#ifdef DEBUG_THUMBNAILS
-	g_message ("(Remove from queue) Unlocking mutex\n");
-#endif
+	DEBUG ("(Remove from queue) Unlocking mutex");
+
 	pthread_mutex_unlock (&thumbnails_mutex);
 }
 
@@ -320,9 +315,8 @@ nemo_thumbnail_prioritize (const char *file_uri)
 {
 	GList *node;
 
-#ifdef DEBUG_THUMBNAILS
-	g_message ("(Prioritize) Locking mutex\n");
-#endif
+	DEBUG ("(Prioritize) Locking mutex");
+
 	pthread_mutex_lock (&thumbnails_mutex);
 
 	/*********************************
@@ -342,9 +336,8 @@ nemo_thumbnail_prioritize (const char *file_uri)
 	 * MUTEX UNLOCKED
 	 *********************************/
 	
-#ifdef DEBUG_THUMBNAILS
-	g_message ("(Prioritize) Unlocking mutex\n");
-#endif
+	DEBUG ("(Prioritize) Unlocking mutex");
+
 	pthread_mutex_unlock (&thumbnails_mutex);
 }
 
@@ -364,9 +357,8 @@ thumbnail_thread_notify_file_changed (gpointer image_uri)
 	NemoFile *file;
 
 	file = nemo_file_get_by_uri ((char *) image_uri);
-#ifdef DEBUG_THUMBNAILS
-	g_message ("(Thumbnail Thread) Notifying file changed file:%p uri: %s\n", file, (char*) image_uri);
-#endif
+
+	DEBUG ("(Thumbnail Thread) Notifying file changed file:%p uri: %s\n", file, (char*) image_uri);
 
 	if (file != NULL) {
 		nemo_file_set_is_thumbnailing (file, FALSE);
@@ -495,9 +487,8 @@ nemo_create_thumbnail (NemoFile *file, gint throttle_count)
 	info->original_file_mtime = file_mtime;
 
 
-#ifdef DEBUG_THUMBNAILS
-	g_message ("(Main Thread) Locking mutex\n");
-#endif
+	DEBUG ("(Main Thread) Locking mutex");
+
 	pthread_mutex_lock (&thumbnails_mutex);
 	
 	/*********************************
@@ -513,10 +504,8 @@ nemo_create_thumbnail (NemoFile *file, gint throttle_count)
 	existing = g_hash_table_lookup (thumbnails_to_make_hash, info->image_uri);
 	if (existing == NULL) {
 		/* Add the thumbnail to the list. */
-#ifdef DEBUG_THUMBNAILS
-		g_message ("(Main Thread) Adding thumbnail: %s\n",
+		DEBUG ("(Main Thread) Adding thumbnail: %s",
 			   info->image_uri);
-#endif
 		g_queue_push_tail ((GQueue *)&thumbnails_to_make, info);
 		node = g_queue_peek_tail_link ((GQueue *)&thumbnails_to_make);
 		g_hash_table_insert (thumbnails_to_make_hash,
@@ -531,10 +520,8 @@ nemo_create_thumbnail (NemoFile *file, gint throttle_count)
 			thumbnail_thread_starter_id = g_idle_add_full (G_PRIORITY_LOW, thumbnail_thread_starter_cb, NULL, NULL);
 		}
 	} else {
-#ifdef DEBUG_THUMBNAILS
-		g_message ("(Main Thread) Updating non-current mtime: %s\n",
+		DEBUG ("(Main Thread) Updating non-current mtime: %s",
 			   info->image_uri);
-#endif
 		/* The file in the queue might need a new original mtime */
 		existing_info = existing->data;
 		existing_info->original_file_mtime = info->original_file_mtime;
@@ -545,9 +532,8 @@ nemo_create_thumbnail (NemoFile *file, gint throttle_count)
 	 * MUTEX UNLOCKED
 	 *********************************/
 
-#ifdef DEBUG_THUMBNAILS
-	g_message ("(Main Thread) Unlocking mutex\n");
-#endif
+	DEBUG ("(Main Thread) Unlocking mutex");
+
 	pthread_mutex_unlock (&thumbnails_mutex);
 }
 
@@ -564,9 +550,9 @@ thumbnail_thread_start (gpointer data)
 	/* We loop until there are no more thumbails to make, at which point
 	   we exit the thread. */
 	for (;;) {
-#ifdef DEBUG_THUMBNAILS
-		g_message ("(Thumbnail Thread) Locking mutex\n");
-#endif
+
+		DEBUG ("(Thumbnail Thread) Locking mutex");
+
 		pthread_mutex_lock (&thumbnails_mutex);
 
 		/*********************************
@@ -595,9 +581,8 @@ thumbnail_thread_start (gpointer data)
 		   thumbnail_thread_is_running flag, unlock the mutex, and
 		   exit the thread. */
 		if (g_queue_is_empty ((GQueue *)&thumbnails_to_make)) {
-#ifdef DEBUG_THUMBNAILS
-			g_message ("(Thumbnail Thread) Exiting\n");
-#endif
+
+			DEBUG ("(Thumbnail Thread) Exiting");
 			thumbnail_thread_is_running = FALSE;
 			pthread_mutex_unlock (&thumbnails_mutex);
 			pthread_exit (NULL);
@@ -613,9 +598,8 @@ thumbnail_thread_start (gpointer data)
 		 * MUTEX UNLOCKED
 		 *********************************/
 
-#ifdef DEBUG_THUMBNAILS
-		g_message ("(Thumbnail Thread) Unlocking mutex\n");
-#endif
+		DEBUG ("(Thumbnail Thread) Unlocking mutex");
+
 		pthread_mutex_unlock (&thumbnails_mutex);
 
 		time (&current_time);
@@ -624,11 +608,9 @@ thumbnail_thread_start (gpointer data)
 		   This prevents constant re-thumbnailing of changing files. */ 
 		if (current_time < current_orig_mtime + (THUMBNAIL_CREATION_DELAY_SECS * info->throttle_count) &&
 		    current_time >= current_orig_mtime) {
-#ifdef DEBUG_THUMBNAILS
-			g_message ("(Thumbnail Thread) Skipping for %d seconds: %s\n",
-                       THUMBNAIL_CREATION_DELAY_SECS * info->throttle_count,
-                       info->image_uri);
-#endif
+			DEBUG ("(Thumbnail Thread) Skipping for %d seconds: %s",
+                   THUMBNAIL_CREATION_DELAY_SECS * info->throttle_count,
+                   info->image_uri);
 			/* Reschedule thumbnailing via a change notification */
 			g_timeout_add_seconds (THUMBNAIL_CREATION_DELAY_SECS * info->throttle_count, thumbnail_thread_notify_file_changed,
 				       g_strdup (info->image_uri));
@@ -636,10 +618,8 @@ thumbnail_thread_start (gpointer data)
 		}
 
 		/* Create the thumbnail. */
-#ifdef DEBUG_THUMBNAILS
-		g_message ("(Thumbnail Thread) Creating thumbnail: %s\n",
+		DEBUG ("(Thumbnail Thread) Creating thumbnail: %s",
 			   info->image_uri);
-#endif
 
 		pixbuf = gnome_desktop_thumbnail_factory_generate_thumbnail (thumbnail_factory,
 									     info->image_uri,
