@@ -26,6 +26,7 @@
 #include "nemo-desktop-window.h"
 #include "nemo-window-private.h"
 #include "nemo-actions.h"
+#include "nemo-desktop-manager.h"
 
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
@@ -48,7 +49,6 @@ enum {
 };
 
 struct NemoDesktopWindowDetails {
-	gulong size_changed_id;
     gint monitor;
 	gboolean loaded;
 };
@@ -58,6 +58,23 @@ static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 G_DEFINE_TYPE (NemoDesktopWindow, nemo_desktop_window, 
 	       NEMO_TYPE_WINDOW);
 
+static void
+nemo_desktop_window_update_directory (NemoDesktopWindow *window)
+{
+	GFile *location;
+
+	g_assert (NEMO_IS_DESKTOP_WINDOW (window));
+
+	window->details->loaded = FALSE;
+
+    location = g_file_new_for_uri (EEL_DESKTOP_URI);
+
+	nemo_window_go_to (NEMO_WINDOW (window), location);
+	window->details->loaded = TRUE;
+
+	g_object_unref (location);
+}
+
 static void
 nemo_desktop_window_dispose (GObject *obj)
 {
@@ -80,7 +97,10 @@ nemo_desktop_window_constructed (GObject *obj)
 	NemoWindow *nwindow = NEMO_WINDOW (obj);
 
 	G_OBJECT_CLASS (nemo_desktop_window_parent_class)->constructed (obj);
-	
+
+    g_object_set_data (G_OBJECT (window), "monitor_number",
+                       GINT_TO_POINTER (window->details->monitor));
+
 	gtk_widget_hide (nwindow->details->statusbar);
 	gtk_widget_hide (nwindow->details->menubar);
 
@@ -103,20 +123,12 @@ nemo_desktop_window_constructed (GObject *obj)
 		atk_object_set_name (accessible, _("Desktop"));
 	}
 
-    GdkRectangle rect;
-
-    nemo_desktop_utils_get_monitor_geometry (window->details->monitor, &rect);
-
-    DEBUG ("NemoDesktopWindow monitor:%d: x:%d, y:%d, w:%d, h:%d",
-           window->details->monitor,
-           rect.x, rect.y,
-           rect.width, rect.height);
-
-    gtk_window_move (GTK_WINDOW (window), rect.x, rect.y);
-    gtk_widget_set_size_request (GTK_WIDGET (window), rect.width, rect.height);
+    nemo_desktop_window_update_geometry (window);
 
     gtk_window_set_resizable (GTK_WINDOW (window),
                   FALSE);
+    gtk_window_set_decorated (GTK_WINDOW (window),
+                  FALSE);
 
     gtk_widget_show (GTK_WIDGET (window));
 }
@@ -170,34 +182,16 @@ nemo_desktop_window_init (NemoDesktopWindow *window)
 	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (window)), "nemo-desktop-window");
 }
 
-static gint
-nemo_desktop_window_delete_event (NemoDesktopWindow *window)
-{
-	/* Returning true tells GTK+ not to delete the window. */
-	return TRUE;
-}
-
-void
-nemo_desktop_window_update_directory (NemoDesktopWindow *window)
-{
-	GFile *location;
-
-	g_assert (NEMO_IS_DESKTOP_WINDOW (window));
-
-	window->details->loaded = FALSE;
-	location = g_file_new_for_uri (EEL_DESKTOP_URI);
-	nemo_window_go_to (NEMO_WINDOW (window), location);
-	window->details->loaded = TRUE;
-
-	g_object_unref (location);
-}
-
 NemoDesktopWindow *
 nemo_desktop_window_new (gint monitor)
 {
+	GApplication *application;
 	NemoDesktopWindow *window;
 
+	application = g_application_get_default ();
+
     window = g_object_new (NEMO_TYPE_DESKTOP_WINDOW,
+			               "application", application,                           
                            "disable-chrome", TRUE,
                            "monitor", monitor,
                            NULL);
@@ -209,8 +203,6 @@ nemo_desktop_window_new (gint monitor)
     gtk_window_set_default_size (GTK_WINDOW (window), -1, -1);
 #endif
 
-    g_signal_connect (window, "delete_event", G_CALLBACK (nemo_desktop_window_delete_event), NULL);
-
     GdkRGBA transparent = {0, 0, 0, 0};
     gtk_widget_override_background_color (GTK_WIDGET (window), 0, &transparent);
 
@@ -222,6 +214,14 @@ nemo_desktop_window_new (gint monitor)
 	return window;
 }
 
+static gboolean
+nemo_desktop_window_delete_event (GtkWidget *widget,
+                                  GdkEventAny *event)
+{
+	/* Returning true tells GTK+ not to delete the window. */
+	return TRUE;
+}
+
 static void
 map (GtkWidget *widget)
 {
@@ -314,6 +314,7 @@ nemo_desktop_window_class_init (NemoDesktopWindowClass *klass)
 	wclass->realize = realize;
 	wclass->unrealize = unrealize;
 	wclass->map = map;
+	wclass->delete_event = nemo_desktop_window_delete_event;
 
 	nclass->sync_title = real_sync_title;
 	nclass->get_icon = real_get_icon;
@@ -341,3 +342,21 @@ nemo_desktop_window_get_monitor (NemoDesktopWindow *window)
 {
     return window->details->monitor;
 }
+
+void
+nemo_desktop_window_update_geometry (NemoDesktopWindow *window)
+{
+    GdkRectangle rect;
+
+    nemo_desktop_manager_get_window_rect_for_monitor (nemo_desktop_manager_get (),
+                                                      window->details->monitor,
+                                                      &rect);
+
+    DEBUG ("NemoDesktopWindow monitor:%d: x:%d, y:%d, w:%d, h:%d",
+           window->details->monitor,
+           rect.x, rect.y,
+           rect.width, rect.height);
+
+    gtk_window_move (GTK_WINDOW (window), rect.x, rect.y);
+    gtk_widget_set_size_request (GTK_WIDGET (window), rect.width, rect.height);
+}
