@@ -1244,8 +1244,7 @@ create_popup_menu (FMTreeView *view)
 	
 	
 	/* add the "open" menu item */
-	menu_image = gtk_image_new_from_stock (GTK_STOCK_OPEN,
-					       GTK_ICON_SIZE_MENU);
+	menu_image = gtk_image_new_from_icon_name ("folder-open-symbolic", GTK_ICON_SIZE_MENU);
 	gtk_widget_show (menu_image);
 	menu_item = gtk_image_menu_item_new_with_mnemonic (_("_Open"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
@@ -1299,7 +1298,10 @@ create_popup_menu (FMTreeView *view)
 	eel_gtk_menu_append_separator (GTK_MENU (popup));
 	
 	/* add the "cut folder" menu item */
-	menu_item = gtk_image_menu_item_new_from_stock (GTK_STOCK_CUT, NULL);
+    menu_image = gtk_image_new_from_icon_name ("edit-cut-symbolic", GTK_ICON_SIZE_MENU);
+    gtk_widget_show (menu_image);
+    menu_item = gtk_image_menu_item_new_with_mnemonic (_("Cu_t"));
+    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), menu_image);
 	g_signal_connect (menu_item, "activate",
 			  G_CALLBACK (fm_tree_view_cut_cb),
 			  view);
@@ -1308,7 +1310,10 @@ create_popup_menu (FMTreeView *view)
 	view->details->popup_cut = menu_item;
 	
 	/* add the "copy folder" menu item */
-	menu_item = gtk_image_menu_item_new_from_stock (GTK_STOCK_COPY, NULL);
+    menu_image = gtk_image_new_from_icon_name ("edit-copy-symbolic", GTK_ICON_SIZE_MENU);
+    gtk_widget_show (menu_image);
+    menu_item = gtk_image_menu_item_new_with_mnemonic (_("_Copy"));
+    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), menu_image);
 	g_signal_connect (menu_item, "activate",
 			  G_CALLBACK (fm_tree_view_copy_cb),
 			  view);
@@ -1317,8 +1322,7 @@ create_popup_menu (FMTreeView *view)
 	view->details->popup_copy = menu_item;
 	
 	/* add the "paste files into folder" menu item */
-	menu_image = gtk_image_new_from_stock (GTK_STOCK_PASTE,
-					       GTK_ICON_SIZE_MENU);
+	menu_image = gtk_image_new_from_icon_name ("edit-paste-symbolic", GTK_ICON_SIZE_MENU);
 	gtk_widget_show (menu_image);
 	menu_item = gtk_image_menu_item_new_with_mnemonic (_("_Paste Into Folder"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
@@ -1333,7 +1337,7 @@ create_popup_menu (FMTreeView *view)
 	eel_gtk_menu_append_separator (GTK_MENU (popup));
 	
 	/* add the "move to trash" menu item */
-	menu_image = gtk_image_new_from_icon_name (NEMO_ICON_TRASH_FULL,
+	menu_image = gtk_image_new_from_icon_name (NEMO_ICON_SYMBOLIC_TRASH_FULL,
 						   GTK_ICON_SIZE_MENU);
 	gtk_widget_show (menu_image);
 	menu_item = gtk_image_menu_item_new_with_mnemonic (_("Mo_ve to Trash"));
@@ -1390,7 +1394,10 @@ create_popup_menu (FMTreeView *view)
 		GTK_WIDGET (eel_gtk_menu_append_separator (GTK_MENU (popup)));
 
 	/* add the "properties" menu item */
-	menu_item = gtk_image_menu_item_new_from_stock (GTK_STOCK_PROPERTIES, NULL);
+    menu_image = gtk_image_new_from_icon_name ("document-properties-symbolic", GTK_ICON_SIZE_MENU);
+    gtk_widget_show (menu_image);
+    menu_item = gtk_image_menu_item_new_with_mnemonic (_("P_roperties"));
+    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), menu_image);
 	g_signal_connect (menu_item, "activate",
 			  G_CALLBACK (fm_tree_view_properties_cb),
 			  view);
